<?php

namespace Drupal\content_reporting\Plugin\QueueWorker;

use Drupal\Core\Database\Connection;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes content interaction tracking tasks.
 *
 * @QueueWorker(
 *   id = "content_reporting_interactions_queue",
 *   title = @Translation("Content Reporting Interaction Worker"),
 *   cron = {"time" = 60}
 * )
 */
class ContentReportingInteractionWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, Connection $database) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->database = $database;
  }

  /**
   *
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    // Save the interaction in the database.
    $this->database->insert('content_reporting_interactions')
      ->fields([
        'nid' => $data['nid'],
        'uid' => $data['uid'],
        'interaction_type' => $data['interaction_type'],
        'element' => $data['element'],
        'duration' => $data['duration'],
        'timestamp' => $data['timestamp'],
      ])
      ->execute();
  }

}
