<?php

namespace Drupal\content_reporting\Plugin\QueueWorker;

use Drupal\Core\Database\Connection;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes content tracking tasks.
 *
 * @QueueWorker(
 *   id = "content_reporting_track_queue",
 *   title = @Translation("Content Reporting Track Worker"),
 *   cron = {"time" = 60}
 * )
 */
class ContentReportingTrackWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, Connection $database) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->database = $database;
  }

  /**
   *
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $consent = is_null($data['gdpr_consent']) ? NULL : (int) $data['gdpr_consent'];
    // Insert or update the record in the database.
    $query = $this->database->merge('content_reporting_reports')
      ->key(['nid' => $data['nid'], 'uid' => $data['uid']])
      ->fields([
        'title' => $data['title'],
        'views' => 1,
        'report_date' => $data['report_date'],
      ])
      ->expression('views', 'COALESCE(views, 0) + 1');

    // Update the GDPR consent count if consent was given (gdpr_consent == 1)
    if ($consent == TRUE) {
      $query->expression('gdpr_consent', 'COALESCE(gdpr_consent, 0) + 1');
    }
    // Execute the query for the main record.
    $query->execute();
  }

}
